(define-module (glicid packages dns)
               #:use-module (guix build-system gnu)
               #:use-module (guix download)
               #:use-module ((guix licenses) #:prefix license:)
               #:use-module (guix packages)
               #:use-module (guix utils)
               #:use-module (gnu packages linux)
               #:use-module (gnu packages libevent)
               #:use-module (gnu packages perl)
               #:use-module (gnu packages pkg-config)
               #:use-module (gnu packages python)
               #:use-module (gnu packages python-xyz)
               #:use-module (gnu packages tls)
               #:use-module (gnu packages xml)
               #:use-module (glicid packages web))

(define-public isc-bind
               (package
                 (name "bind")
                 (version "9.18.19")
                 (source (origin
                           (method url-fetch)
                           (uri (list (string-append "https://downloads.isc.org/isc/bind9/" version "/bind-" version ".tar.xz")))
                           (sha256 (base32 "1k0jfv9a91wcb28gdply29h3psw8z84dlbi73pgbmgirak00jphi"))))
                 (build-system gnu-build-system)
                 (outputs `("out" "utils"))
                 (inputs
                   (list libcap libuv libxml2 openssl p11-kit python `(,nghttp2 "lib") python-ply))
                 (native-inputs
                   (list perl pkg-config))
                 (arguments
                   `(
                     #:configure-flags
                     (list  "--with-sysroot=/")
                     #:phases
                     (modify-phases %standard-phases
                                    (add-after 'strip 'move-to-utils
                                               (lambda _
                                                 (for-each
                                                   (lambda (file)
                                                     (let ((target (string-append (assoc-ref %outputs "utils") file))
                                                           (src (string-append (assoc-ref %outputs "out") file)))
                                                       (mkdir-p (dirname target))
                                                       (link src target)
                                                       (delete-file src)))
                                                   '("/bin/dig" "/bin/delv" "/bin/nslookup" "/bin/host" "/bin/nsupdate"
                                                     "/share/man/man1/dig.1" "/share/man/man1/host.1" "/share/man/man1/nslookup.1"
                                                     "/share/man/man1/nsupdate.1"))
                                                 #t))
                                    (replace 'check
                                             (lambda _
                                               (with-directory-excursion "fuzz" (invoke "make" "check"))
                                               #t)))))
                 (synopsis "@acronym{DNS, Domain Name System} implementation")
                 (description "BIND implements the @acronym{DNS, Domain Name System} protocols for the Internet. check gnu/packages/dns for more")
                 (home-page "https://www.isc.org/bind/")
                 (license (list license:mpl2.0))))
